@@ -491,7 +491,7 @@ class Auth(object):
             'user': self.settings['mysql_servers']['help']['db_user'],
             'password': self.settings['mysql_servers']['help']['db_pass'],
             'db': self.settings['mysql_servers']['help']['db'],
-            'charset': 'latin1',
+            'charset': 'utf-8',
             'verbose': self.verbose,
         })
         return RequestTracker(**params)
@@ -805,7 +805,7 @@ class Auth(object):
             'user': self.settings['mysql_servers']['rt']['db_user'],
             'password': self.settings['mysql_servers']['rt']['db_pass'],
             'db': self.settings['mysql_servers']['rt']['db'],
-            'charset': 'latin1',
+            'charset': 'utf-8',
             'verbose': self.verbose,
         })
         return RequestTracker(**params)
